# pitchmark

Exploring golf shot strategy.

[![PyPI](https://img.shields.io/pypi/v/pitchmark)](https://pypi.org/project/pitchmark/)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pitchmark)
[![Codecov branch](https://img.shields.io/codecov/c/github/istvankleijn/pitchmark/master)](https://app.codecov.io/gh/istvankleijn/pitchmark)

## Installation

```bash
$ pip install pitchmark
```

## Usage

- TODO

## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## License

`pitchmark` was created by Istvan Kleijn. It is licensed under the terms of the MIT license.

## Credits

The test suite includes raw map data from [OpenStreetMap](https://www.openstreetmap.org/copyright).

`pitchmark` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).
